aboutsummaryrefslogtreecommitdiffstats
path: root/src/decoder/DecoderAPI.hxx
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/decoder/DecoderAPI.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/decoder/DecoderAPI.hxx b/src/decoder/DecoderAPI.hxx
index ca33e26c7..b756331d9 100644
--- a/src/decoder/DecoderAPI.hxx
+++ b/src/decoder/DecoderAPI.hxx
@@ -53,12 +53,13 @@ class Error;
* @param audio_format the audio format which is going to be sent to
* decoder_data()
* @param seekable true if the song is seekable
* @param total_time the total number of seconds in this song; -1 if unknown
*/
void
decoder_initialized(Decoder &decoder,
AudioFormat audio_format,
- bool seekable, float total_time);
+ bool seekable, SignedSongTime duration);
/**
* Determines the pending decoder command.
@@ -53,12 +53,13 @@ class Error;
* decoder_data()
* @param seekable true if the song is seekable
- * @param total_time the total number of seconds in this song; -1 if unknown
+ * @param duration the total duration of this song; negative if
+ * unknown
*/
void